#include <my_global.h>
#include <my_sys.h>
#include <getopt.h>
#include <stdio.h>

#define INCLUDE "-I/usr/include -I/usr/include/mariadb"
#define LIBS    "-L/usr/lib64/mariadb -lmariadb" \
                " -lssl -ldl -lm -lpthread"
#define PRIVATE_LIBS "-L/usr/lib64/mariadb -lmariadbprivate" \
                " -lssl -ldl -lm -lpthread"
#define CFLAGS  INCLUDE " -fmessage-length=0 -grecord-gcc-switches -O2 -Wall -D_FORTIFY_SOURCE=2 -fstack-protector -funwind-tables -fasynchronous-unwind-tables -g -DNDEBUG -Wunused -Wno-uninitialized"
#define VERSION "5.5.1"
#define PLUGIN_DIR "/usr/lib64/mariadb/plugin/"
#define SOCKET  "/run/mysql/mysql.sock"
#define PORT "3306"

static struct option long_options[]=
{
  {"cflags", no_argument, 0, 'a'},
  {"help", no_argument, 0, 'b'},
  {"include", no_argument, 0, 'c'},
  {"libs", no_argument, 0, 'd'},
  {"libs_r", no_argument, 0, 'e'},
  {"version", no_argument, 0, 'f'},
  {"socket", no_argument, 0, 'g'},
  {"port", no_argument, 0, 'h'},
  {"privatelibs", no_argument, 0, 'i'},
  {"plugindir", no_argument, 0, 'p'},
  {NULL, 0, 0, 0}
};

static char *values[]=
{
  CFLAGS,
  NULL,
  INCLUDE,
  LIBS,
  LIBS,
  VERSION,
  SOCKET,
  PORT,
  PRIVATE_LIBS,
  PLUGIN_DIR
};

void usage(void)
{
  int i=0;
  puts("Copyright 2011-2015 MariaDB Corporation AB");
  puts("Get compiler flags for using the MariaDB Connector/C.");
  printf("Usage: %s [OPTIONS]\n", my_progname);
  while (long_options[i].name)
  {
    if (values[i])
      printf("  --%-12s  [%s]\n", long_options[i].name, values[i]);
    i++;
  }
}

int main(int argc, char **argv)
{
  int c;
  my_progname= argv[0];

  if (argc <= 1)
  {
    usage();
    exit(1);
  }

  while(1)
  {
    int option_index= 0;
    c= getopt_long(argc, argv, "abcdef", long_options, &option_index);

    switch(c) {
    case 'a':
      puts(CFLAGS);
      break;
    case 'b':
      usage();
      break;
    case 'c':
      puts(INCLUDE);
      break;
    case 'd':
    case 'e':
      puts(LIBS);
      break;
    case 'f':
      puts(VERSION);
      break;
    case 'g':
      puts(SOCKET);
      break;
    case 'h':
      puts(PORT);
      break;
    case 'i':
      puts(PRIVATE_LIBS);
      break;
    case 'p':
      puts(PLUGIN_DIR);
      break;
    default:
      exit(0);
    }
  }

  exit(0);
}

